#
# spec file for package python-fudge
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-fudge
Version:        1.1.1
Release:        6.9
Summary:        Module for replacing real objects with fakes (mocks, stubs, etc) while testing
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/fudge-py/fudge
Source:         https://files.pythonhosted.org/packages/source/f/fudge/fudge-%{version}.tar.gz
Patch0:         remove_nose.patch
Patch1:         no2to3.patch
BuildRequires:  %{python_module modernize}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
Fudge is a Python module for using fake objects (mocks and stubs) to test real ones.

In readable Python code, you declare what methods are available on your fake and
how they should be called. Then you inject that into your application and start
testing. This declarative approach means you don't have to record and playback
actions and you don't have to inspect your fakes after running code. If the fake
object was used incorrectly then you'll see an informative exception message
with a traceback that points to the culprit.

%prep
%setup -q -n fudge-%{version}
%autopatch -p1

python-modernize -w fudge/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#fudge-py/fudge#11
# Two still unported tests
%pytest -k 'not (test_decorator_on_def or test_expectations_are_always_cleared)'

%files %{python_files}
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Tue Mar  1 2022 Dirk Müller <dmueller@suse.com>
- add no2to3.patch to improve compatibility with newer setuptools
* Tue Jan 19 2021 John Vandenberg <jayvdb@gmail.com>
- Use python-modernize
- Reduce remove_nose.patch to modifications of tests only,
  and re-enable two more tests
- Update URL
- Trim description
* Wed Apr 22 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch which removes need to use nose, and ports
  the package to py3k-compatible syntax. (gh#fudge-py/fudge#11)
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Skip the tests for the flavors not being built
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.1:
  * no changelog provided
- Do not bother with sphinx docu as the upstream homepage is
  the docu itself
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Dec 11 2017 mimi.vx@gmail.com
- add missing BuildRequires for python3-2to3
* Fri Oct  6 2017 jmatejek@suse.com
- singlespec auto-conversion
- fix doc generation
- fix test runner
- update to 1.1.0
  * no changelog provided
* Wed Mar  9 2016 bwiedemann@suse.com
- Drop build date from doc to fix build-compare
* Mon Feb 20 2012 saschpe@gmx.de
- Initial version
